quantizationtools.BeatwiseQSchemaItem
=====================================

.. abjad-lineage:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem

.. autoclass:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.beatspan
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.search_tree
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.tempo
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__eq__
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__format__
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__hash__
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__ne__
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__repr__

Bases
-----

- :py:class:`quantizationtools.QSchemaItem <abjad.tools.quantizationtools.QSchemaItem.QSchemaItem>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.beatspan
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.tempo
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem.__repr__
   :noindex:
